// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "remoting/base/constants.h"

namespace remoting {

const char kChromotingBotJid[] = "remoting@bot.talk.google.com";

const char kChromotingTokenDefaultServiceName[] = "chromiumsync";

const char kChromotingXmlNamespace[] = "google:remoting";

const char kVideoChannelName[] = "video";
const char kVideoRtpChannelName[] = "videortp";
const char kVideoRtcpChannelName[] = "videortpc";

}  // namespace remoting
